@@ -1,10 +1,8 @@
-from unittest2 import TestCase
+from tests import TestCase
 
 from exam import Exam, fixture
 from exam.asserts import AssertsMixin
 
-from describe import expect
-
 
 class AssertChangesMixin(Exam, TestCase):
 
@@ -33,13 +31,13 @@ class AssertChangesMixin(Exam, TestCase):
     def test_verifies_value_must_change_no_matter_what(self):
         self.thing.append(1)
 
-        with expect.to_raise_error(AssertionError):
+        with self.assertRaises(AssertionError):
             self.no_op_context(after=1)
 
-        with expect.to_raise_error(AssertionError):
+        with self.assertRaises(AssertionError):
             self.no_op_context(before=1)
 
-        with expect.to_raise_error(AssertionError):
+        with self.assertRaises(AssertionError):
             self.no_op_context()
 
     def test_reraises_exception_if_raised_in_context(self):
@@ -53,6 +51,13 @@ class AssertChangesMixin(Exam, TestCase):
             pass
 
     def test_raises_assertion_error_if_value_changes(self):
-        with self.assertRaisesRegexp(AssertionError, '=='):
+        msg = 'Value changed from 0 to 1'
+        with self.assertRaisesRegexp(AssertionError, msg):
             with self.assertDoesNotChange(len, self.thing):
                 self.thing.append(1)
+
+    def test_assertion_error_mentions_unexpected_result_at_after(self):
+        msg = 'Value changed to 1, not 3'
+        with self.assertRaisesRegexp(AssertionError, msg):
+            with self.assertChanges(len, self.thing, after=3):
+                self.thing.append(1)
\ No newline at end of file
