@@ -1,5 +1,4 @@
-from unittest2 import TestCase
-from describe import expect
+from tests import TestCase
 
 from exam.decorators import fixture
 
@@ -46,30 +45,30 @@ class ExtendedDummy(Dummy):
 class TestFixture(TestCase):
 
     def test_converts_method_to_property(self):
-        expect(Dummy().number).to == 42
+        self.assertEqual(Dummy().number, 42)
 
     def test_caches_property_on_same_instance(self):
         instance = Dummy()
-        expect(instance.obj).to.be_equal_to(instance.obj)
+        self.assertEqual(instance.obj, instance.obj)
 
     def test_gives_different_object_on_separate_instances(self):
-        expect(Dummy().obj).to_not.be_equal_to(Dummy().obj)
+        self.assertNotEqual(Dummy().obj, Dummy().obj)
 
     def test_can_be_used_inline_with_a_function(self):
-        expect(Dummy().inline_func).to == 'value from outside'
+        self.assertEqual(Dummy().inline_func, 'value from outside')
 
     def test_can_be_used_with_a_callable_that_takes_args(self):
         inst = Dummy()
-        expect(inst.inline_func_with_args).to == ((inst, 1, 2), dict(a=3))
+        self.assertEqual(inst.inline_func_with_args, ((inst, 1, 2), dict(a=3)))
 
     def test_can_be_used_with_class_method(self):
-        expect(Dummy().inline_from_method).to == (Outer, 'from method')
+        self.assertEqual(Dummy().inline_from_method, (Outer, 'from method'))
 
     def test_if_passed_type_builds_new_object(self):
-        expect(Dummy().inline).to == 5
+        self.assertEqual(Dummy().inline, 5)
 
     def test_override_in_subclass_overrides_value(self):
-        expect(ExtendedDummy().number).to == 42 + 42
+        self.assertEqual(ExtendedDummy().number, 42 + 42)
 
     def test_captures_identical_funcs_with_args_separatly(self):
         instance = Dummy()
@@ -77,4 +76,4 @@ class TestFixture(TestCase):
         first = instance.inline_from_method_with_arg_1
         second = instance.inline_from_method_with_arg_2
 
-        expect(first).to != second
+        self.assertNotEqual(first, second)
